#
# spec file for package python-idna
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-idna
Version:        2.6
Release:        lp152.3.2
Summary:        Internationalized Domain Names in Applications (IDNA)
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/kjd/idna
Source0:        https://files.pythonhosted.org/packages/source/i/idna/idna-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%python_subpackages

%description
A library to support the Internationalised Domain Names in
Applications (IDNA) protocol as specified in RFC 5891
http://tools.ietf.org/html/rfc5891. This version of the protocol
is often referred to as “IDNA2008” and can produce different
results from the earlier standard from 2003.

The library is also intended to act as a suitable drop-in replacement
for the “encodings.idna” module that comes with the Python standard
library but currently only supports the older 2003 specification.

%prep
%setup -q -n idna-%{version}

%build
%python_build

%install
%python_install

%check
%python_exec setup.py test

%files %python_files
%defattr(-,root,root,-)
%doc HISTORY.rst  LICENSE.rst README.rst
%{python_sitelib}/*

%changelog
* Thu Nov  9 2017 arun@gmx.de
- update to version 2.6:
  * Allows generation of IDNA and UTS 46 table data for different
    versions of Unicode, by deriving properties directly from Unicode
    data.
  * Ability to generate RFC 5892/IANA-style table data
  * Diagnostic output of IDNA-related Unicode properties and derived
    calculations for a given codepoint
  * Support for idna.__version__ to report version
  * Support for idna.idnadata.__version__ and
    idna.uts46data.__version__ to report Unicode version of underlying
    IDNA and UTS 46 data respectively.
* Tue Mar 21 2017 jmatejek@suse.com
- point download url to PyPI
- drop %%oname
* Thu Mar 16 2017 tbechtold@suse.com
- update to version v2.5
  * only store scripts that are specifically referenced in logic
  * Fix validation for U+30FB KATAKANA MIDDLE DOT code point (#47)
  * range-based integer containment code
  * Documentation Updates
  * Make test runners Python 2.6 compatible (issue #20)
  * remove DISALLOWED codepoints from datafile, since they're unread
  * Avoid using bare 'except' (#39)
  * Add Python 3.5 support
  * Mark Python Wheels as universal (supports Python 2 and 3)
  * Skip tests that won't work on Python 2.6 (fixes #20)
  * Update Travis configuration to test against Python 2.6 and 3.6
  * Use relative imports (fixes #26)
  * Documentation tidy up
  * Revert to basing IDNAError on UnicodeError (issue #43) (#45)
  * rebuild idnadata
  * Update history with Java-related change
  * ignore vim swapfiles
  * Update Travis CI coverage to 3.6 and 3.7-dev
  * Reduce memory usage even further. (#41)
  * Update trove classifier for Python 3.6
  * Properly report label length exceptions (issue #36)
  * Segment uts46data to avoid Jython limits (#28)
- Switch to singlespec approach
* Fri Jul 17 2015 nemysis@gmx.ch
- Initial package creation
